# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime


class InferenceCreateByPromptId(pydantic.BaseModel):
    """
    Create inference by `prompt_id`. It can only be used if there is at least one 'Live' status prompt version for the provided `prompt_id`.
    If there are multiple prompt versions in Live status it will pick one randomly. Useful for split testing prompt versions.
    It stores all other `prompt_version_id`s in Live status at the time of the inference in `prompt_version_ids_considered` field.
    """

    end_user_id: typing.Optional[str] = pydantic.Field(
        description=(
            "The API consumer's internal user reference for metrics. It is also relayed to the provider as part of the request if the provider supports it (eg. OpenAI's user field).\n"
        )
    )
    source: typing.Optional[str] = pydantic.Field(
        description=("The API consumer's source for metrics (e.g. AndroidApp etc).\n")
    )
    client_ref_id: typing.Optional[str] = pydantic.Field(
        description=("The API consumer's internal reference id to able to link references to their sessions.\n")
    )
    template_args: typing.Optional[typing.Dict[str, str]]
    metadata: typing.Optional[typing.Dict[str, typing.Any]]
    request_timeout: typing.Optional[float] = pydantic.Field(
        description=(
            "Provider request timout in seconds. If not provided, then Prompton API's default timeout for the provider will be used (90sec or `DEFAULT_OPENAI_REQUEST_TIMEOUT_SECONDS` env var if provided).\n"
        )
    )
    prompt_id: str

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .inference_read_response import InferenceReadResponse
from .inference_request_data import InferenceRequestData
from .inference_response_status import InferenceResponseStatus


class InferenceRead(pydantic.BaseModel):
    id: typing.Optional[str] = pydantic.Field(alias="_id")
    created_at: typing.Optional[str]
    created_by_user_id: typing.Optional[str]
    created_by_org_id: typing.Optional[str]
    end_user_id: typing.Optional[str] = pydantic.Field(
        description=(
            "The API consumer's internal user reference for metrics. It is also relayed to the provider as part of the request if the provider supports it (eg. OpenAI's user field).\n"
        )
    )
    source: typing.Optional[str] = pydantic.Field(
        description=("The API consumer's source for metrics (e.g. AndroidApp etc).\n")
    )
    client_ref_id: typing.Optional[str] = pydantic.Field(
        description=("The API consumer's internal reference id to able to link references to their sessions.\n")
    )
    template_args: typing.Optional[typing.Dict[str, str]]
    metadata: typing.Optional[typing.Dict[str, typing.Any]]
    request_timeout: typing.Optional[float] = pydantic.Field(
        description=(
            "Provider request timout in seconds. If not provided, then Prompton API's default timeout for the provider will be used (90sec or `DEFAULT_OPENAI_REQUEST_TIMEOUT_SECONDS` env var if provided).\n"
        )
    )
    prompt_version_id: str
    prompt_version_ids_considered: typing.Optional[typing.List[str]] = pydantic.Field(
        description=(
            "If inference was by prompt_id then a list of all other prompt versions considered for this inference. I.e. all prompt versions in Live status at the time of the inference\n"
        )
    )
    prompt_id: str
    prompt_version_name: typing.Optional[str]
    status: typing.Optional[InferenceResponseStatus]
    request: typing.Optional[InferenceRequestData]
    response: typing.Optional[InferenceReadResponse]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        allow_population_by_field_name = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing

from .inference_create_by_prompt_id import InferenceCreateByPromptId
from .inference_create_by_prompt_version_id import InferenceCreateByPromptVersionId

NewInferenceRequest = typing.Union[InferenceCreateByPromptVersionId, InferenceCreateByPromptId]
